# MT-NumericEntities
#
# Copyright, Jacques Distler 2005.
# All Rights Reserved.
# Licensed under the Perl Artistic License.
#
# Version: 0.1.1
#
# Adds a global filter to convert XHTML and MathML named entities
# into numeric character references. The five "safe" entities
# (&amp;, &lt; &gt; &apos; &quot;) defined by in XML 1.0 are untouched.
#
# Usage:
#
#        <MTEntryBody numeric_entities="1">
#

package MT::Plugin::NumericEntities;

use strict;
use MT;
use MT::Template::Context;
use vars qw($VERSION);
$VERSION = '0.1';

eval{ require MT::Plugin };
unless ($@) {
    my $plugin = {
        name => "NumericEntities $VERSION",
        description => 'Turn XHTML and MathML named entities into numeric
            character references. This makes the resulting XML safe for
            consumption by a generic XML parser.',
        doc_link => 'http://golem.ph.utexas.edu/~distler/blog/NumericEntities.html'
    }; 
    MT->add_plugin(new MT::Plugin($plugin));
}


MT::Template::Context->add_global_filter('numeric_entities', \&make_numeric);

sub make_numeric {
  require MathML::Entities;
  my ($text, $arg, $ctx) = @_;
  if ($arg == 1) {
      MathML::Entities::name2numbered($text);
  } elsif ($arg ==2) {
      MathML::Entities::name2utf8($text);
  } else {
      $text;
  }
}

1;
